@@ -32,7 +32,7 @@ def prepare_screenshots(cnf: Configuration) -> None:
     print("2. The lower-right corner of the area to screenshot")
     print("3. The location where to click for the next page")
     print("4. Click on the screenshot to close the window")
-    wait(4)
+    wait(2)
 
     tmp_filename = cnf.path("__tmp.png")
     img = pyautogui.screenshot()
@@ -100,7 +100,7 @@ def make_screenshot(file_name: str, cnf: Configuration, scale: float=1) -> Any:
     img.save(file_name)
 
 def test_screenshot(cnf: Configuration) -> None:
-    wait(4)
+    wait(2)
     print()
     print("Click on the screenshot to close")
     tmp_file = cnf.path("example_screenshot.png")
@@ -149,13 +149,17 @@ def prepare_image(file_in: str, bw: bool=False, page: str="", resize: float=1) -
     return out
 
 
-def export_to_pdf(cnf: Configuration) -> None:
+def get_screenshots(cnf: Configuration) -> List[str]:
     original_files: List[str] = []
     file = ""
     for file in os.listdir(cnf.work_dir):
         if file.startswith(screenshot_prefix):
             original_files.append(file)
     original_files.sort()
+    return original_files
+
+def export_to_pdf(cnf: Configuration) -> None:
+    original_files = get_screenshots(cnf)
 
     pages = 0
     try: pages = int(input("Last page no (or leave empty for no pagination): "))
@@ -171,20 +175,65 @@ def export_to_pdf(cnf: Configuration) -> None:
                 label += f" of {pages}"
         print(f"{n}/{len(original_files)}: {file}")
         processed_images.append(prepare_image(cnf.path(file), bw=cnf.convert_to_bw, page=label, resize=cnf.resize_ratio))
-    
-    outfile = cnf.path("exported.pdf")
+
+    filename = ""
+    for c in cnf.work_dir:
+        filename += c if c.isalnum() or c.isalpha() else "_"
+
+    outfile = cnf.path(filename + ".pdf" if filename else "exported.pdf")
     print(f"Converting to {outfile}")
     im1 = processed_images[0]
     im1.save(outfile, save_all=True, append_images=processed_images[1:])
+    print(f"Saved to {filename}")
 
 def take_screenshots(cnf: Configuration) -> None:
     try:
         n = int(input("How many screenshots/pages: "))
     except:
         n = 0
-    wait(4)
+    take_n_screenshots(cnf, n)
 
-    for i in range(n):
+def screenshots_the_rest(cnf: Configuration) -> None:
+    screenshots = get_screenshots(cnf)
+
+    if len(screenshots) <= 5:
+        print("Too few screenshots")
+        take_screenshots(cnf)
+        return
+
+    try: current_document_page = int(input("Current page: "))
+    except: current_document_page = 0
+
+    if current_document_page == 0:
+        take_screenshots(cnf)
+        return
+
+    try: last_document_page = int(input("Last page: "))
+    except: last_document_page = 0
+
+    one_document_page_screenshots = len(screenshots) / current_document_page
+    total_screenshots = last_document_page * one_document_page_screenshots
+    rest = int(total_screenshots - len(screenshots))
+
+    print(f"One document page is ~{one_document_page_screenshots} screenshots")
+    print(f"In total it will be ~{total_screenshots} screenshots")
+    print(f"=> need ~{rest} screenshots")
+
+    try:
+        n = int(input(f"How many screenshots/pages (<enter> for {rest}): "))
+    except:
+        n = rest
+
+    take_n_screenshots(cnf, n)
+
+def take_n_screenshots(cnf: Configuration, count: int) -> None:
+    if count == 0:
+        return
+
+    wait(2)
+
+    started = datetime.datetime.now()
+    for i in range(count):
         now = datetime.datetime.now()
         fn = cnf.path(screenshot_prefix + now.isoformat().replace(":", "_") + ".png")
         make_screenshot(fn, cnf)
@@ -195,7 +244,11 @@ def take_screenshots(cnf: Configuration) -> None:
         time.sleep(0.1)
         pyautogui.mouseUp()
         time.sleep(cnf.sleep)
-        print(f"{i}/{n} -> {fn}")
+        remaining_time_str = ""
+        if i > 0:
+            time_per_screenshot = (datetime.datetime.now() - started) / i
+            remaining_time_str = f" [Remaining time ~{(count - i) * time_per_screenshot}]"
+        print(f"{i}/{count} -> {fn} {remaining_time_str}")
 
 def change_work_dir(cnf: Configuration) -> None:
     dir = input("Enter work directory name:")
@@ -226,10 +279,11 @@ def main_menu() -> None:
     except:
         ratio = "???"
     options.append(("s", lambda cnf: f"Take screenshots (sides ratio: {cnf.x2 - cnf.x1}:{cnf.y2 - cnf.y1}={ratio})", take_screenshots))
+    options.append(("sr", lambda cnf: f"Screenshot the rest of the document", screenshots_the_rest))
     options.append(("w", lambda cnf: f"Wait between screenshowts ({cnf.sleep}s)", wait_time))
     options.append(("r", lambda cnf: f"Resize ({cnf.resize_ratio})", resize_ratio))
     options.append(("b", lambda cnf: f"Convert to black-and-white ({cnf.convert_to_bw})", toggle_bw))
-    options.append(("n", lambda cnf: f"Retina screen ({cnf.retina})", toggle_retina))
+    options.append(("re", lambda cnf: f"Retina screen ({cnf.retina})", toggle_retina))
     options.append(("e", lambda cnf: "Export to pdf", export_to_pdf))
     menu("Select", options, cnf, "q", "Quit")
 
